@@ -2,8 +2,10 @@
 #
 
 dnearneigh <- function(x, d1, d2, row.names=NULL) {
+    if (!is.numeric(x)) stop("Data non-numeric")
     if (!is.matrix(x)) stop("Data not in matrix form")
     if (any(is.na(x))) stop("Data include NAs")
+    if (!is.double(x)) x <- as.double(x)
     np <- nrow(x)
     if (!is.null(row.names)) if(length(row.names) != np)
         stop("row.names wrong length")
@@ -14,7 +16,7 @@ dnearneigh <- function(x, d1, d2, row.names=NULL) {
     if (d1 < 0) d1 <- 0.0
     if (d2 > sqrt(md)) d2 <- sqrt(md)
     z <- .Call("dnearneigh", as.double(d1), as.double(d2), as.integer(np),
-        as.integer(dimension), as.matrix(x), PACKAGE="spdep")
+        as.integer(dimension), as.double(x), PACKAGE="spdep")
     attr(z[[1]], "region.id") <- row.names
     attr(z[[1]], "call") <- match.call()
     attr(z[[1]], "dnn") <- c(d1, d2)
